### emcee_rapper

Welcome to ``emcee_rapper``! ``emcee_rapper`` is a small python package developed at code/astro 2025 that wraps the popular Markov chain Monte Carlo sampling code emcee to make fitting with it even more straightforward. It can help you set up priors and likelihood functions, pass them to emcee, and visualize the fit results.

We are pip installable! ``pip install emcee_rapper`` should do the trick
